@@ -1,8 +1,8 @@
 package App::RecordStream::Bio;
 
 use strict;
-use 5.008_005;
-our $VERSION = '0.04';
+use 5.010;
+our $VERSION = '0.05';
 
 1;
 __END__
